<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:c="http://bulletin.cstug.cz/ns/CSTUGbulletin" version="1.0"
                exclude-result-prefixes="c">

<!--
This stylesheet transforms the list of authors into an HTML table.
-->

<xsl:import href="acro.xsl"/>

<xsl:strip-space elements="*"/>
<xsl:preserve-space elements="c:text c:TeX c:html"/>
<xsl:output method="html"/>

<xsl:variable name="acromode">html</xsl:variable>
<xsl:variable name="index" select="document(/descendant::node()/@indexhref)/c:index"/>
<xsl:variable name="acronymlist" select="document(concat($index/@base,$index/@acronyms))"/>

<xsl:template match="c:authorList">
  <html>
    <head>
      <title>List of Authors</title>
    </head>
    <body background="back_narrow.gif" bgcolor="#ffffff" text="#000000" alink="#c14242" vlink="#d30000" link="#900000">
<table border="0" width="100%">
 <tr valign="top">
  <td width="30"> </td>
  <td>
      <a href="http://bulletin.cstug.cz/xml/">
        <img src="logo.gif" border="0" height="51" width="165" alt="CSTUG" align="right"/>
      </a>
      <h1>List of Authors Sorted by Id, last modified
          <xsl:value-of select="/c:authorList/@lastModified"/></h1>
      <table frame="box" rules="all" border="3" cellpadding="3">
        <tr>
          <th>Id</th>
          <th>Surname</th>
          <th>First name</th>
          <th>Initials</th>
          <th>Full name</th>
        </tr>
        <xsl:for-each select="c:author">
          <xsl:sort select="@id"/>
          <xsl:call-template name="author"/>
        </xsl:for-each>
      </table>
      <p><a title="Index" href="{@indexhref}">Index</a></p>
</td></tr></table>
    </body>
  </html>
</xsl:template>

<xsl:template name="author">
  <tr valign="middle">
    <td><xsl:value-of select="@id"/></td>
    <td><xsl:apply-templates select="c:surname"/></td>
    <td><xsl:apply-templates select="c:firstname"/></td>
    <td><xsl:apply-templates select="c:initials"/></td>
    <td>
      <xsl:choose>
        <xsl:when test="c:fullname">
          <xsl:apply-templates select="c:fullname"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:apply-templates select="c:firstname"/>
          <xsl:text> </xsl:text>
          <xsl:apply-templates select="c:surname"/>
        </xsl:otherwise>
      </xsl:choose>
    </td>
  </tr>
</xsl:template>

<xsl:template match="c:surname|c:firstname|c:initials|c:fullname">
  <xsl:apply-templates/>
</xsl:template>

</xsl:stylesheet>