<?xml version='1.0' encoding='utf-8'?>
<!DOCTYPE xsl:stylesheet [
<!ENTITY c-namespace 'http://bulletin.cstug.cz/ns/CSTUGbulletin'>
]>
<xsl:stylesheet version='1.0' xmlns:xsl='http://www.w3.org/1999/XSL/Transform'
                xmlns:c='&c-namespace;' exclude-result-prefixes='c'>

<!--
Do not use this stylesheet directly, it is designed to be imported into bibliography.xsl or
bibliography2.xsl
-->

<xsl:include href='acro.xsl'/>
<xsl:include href='auth.xsl'/>
<xsl:include href='xinclude.xsl'/>

<xsl:preserve-space elements='c:html c:text'/>
<xsl:param name='acromode'>TeX</xsl:param>
<xsl:param name='lang'>cze</xsl:param>

<xsl:output method='text'/>

<xsl:key name='article' match='//c:article' use='@id'/>

<xsl:template match='c:article'>
  <xsl:copy>
    <xsl:attribute name='year'>
      <xsl:value-of select='substring-before(@id, "/")'/>
    </xsl:attribute>
    <xsl:attribute name='volume'>
      <xsl:value-of select='number(substring-before(@id, "/")) - 1990'/>
    </xsl:attribute>
    <xsl:copy-of select='@*|../@num|../@href|c:author|c:title'/>
  </xsl:copy>
</xsl:template>

<xsl:template match='c:article' mode='TeX'>
  <xsl:value-of
    select='concat("\bibitem{", substring-before(@id, "#"), ":", substring-after(@id, "#"), "}\ignorespaces ")'/>
  <xsl:if test='c:author'>
    <xsl:for-each select='c:author'>
      <xsl:if test='position() &gt; 1'>
        <xsl:text>\unskip, </xsl:text>
      </xsl:if>
      <xsl:apply-templates select='.'/>
    </xsl:for-each>
    <xsl:text>\unskip: </xsl:text>
  </xsl:if>
  <xsl:text>\textbf{\ignorespaces </xsl:text>
  <xsl:choose>
    <xsl:when test='c:title[@lang=$lang]'>
      <xsl:apply-templates select='c:title[@lang=$lang]' mode='TeX'/>
    </xsl:when>
    <xsl:when test='c:title[@lang=../@lang]'>
      <xsl:apply-templates select='c:title[@lang=../@lang]' mode='TeX'/>
    </xsl:when>
    <xsl:when test='c:title[@lang="cze"]'>
      <xsl:apply-templates select='c:title[@lang="cze"]' mode='TeX'/>
    </xsl:when>
    <xsl:otherwise>
      <xsl:apply-templates select='c:title[1]' mode='TeX'/>
    </xsl:otherwise>
  </xsl:choose>
  <xsl:text>\unskip.} </xsl:text>
  <xsl:text>\bul </xsl:text>
  <xsl:value-of select='concat(@volume, "(", @num, ")", @firstPage)'/>
  <xsl:if test='@lastPage'>
    <xsl:value-of select='concat("--", @lastPage)'/>
  </xsl:if>
  <xsl:value-of select='concat("(", @year, ").&#10;")'/>
</xsl:template>

<xsl:template match='/' mode='xinclude'>
  <xsl:apply-templates/>
</xsl:template>

</xsl:stylesheet>
