package cz.cas.icpf.hroch486.selfml.gems;

import cz.cas.icpf.hroch486.selfml.*;

import java.util.List;
import java.util.Enumeration;
import java.util.StringTokenizer;
import java.util.Map;
import java.util.HashMap;

import org.dom4j.Node;
import org.dom4j.Element;
import org.dom4j.Document;
import org.dom4j.DocumentHelper;
import org.dom4j.DocumentException;
import org.dom4j.XPath;
import org.dom4j.QName;
import org.dom4j.Namespace;

/**
This class builds the SELFML file for the GEMS1311 property.
@author Zdenek Wagner
*/

public class Gems1311 implements PropertyBuilder {

    /** Document to be parsed */
    Document document;
    /** namespace map */
    protected Map nsMap;

/**
Allocates the map
*/
    public Gems1311() {
      nsMap = new HashMap();
      nsMap.put("ns", Edip.INTERNAL_NS);
    }

    /** Enumerates property names handled by the class */
    public Enumeration getPropertyNames() {
        return new StringTokenizer("GEMS1311");
    }

/**
Returns the QName for CML namespace with an empty prefix
@param name the local name
@return QName
*/

    public QName getQName(String name) {
      return new QName(name, new Namespace("", CML_NAMESPACE_URI));
    }

/**
Builds the SELFML document from the intermediate document
@param document the intermediate document returned by the spreadsheet parser
@return SELFML document
@exception EdipException reason of error
*/
    public Document build(Document document) throws EdipException {
        this.document = document;
        document = DocumentHelper.createDocument();
        Element root = document.addElement(getQName("selfList"));
        Element self = root.addElement(getQName("self"))
                           .addAttribute("propertyTypeRef", "GEMS1311");

        System.out.println("Building GEMS1311");

        // The description block must contain 6 names
        List descriptionBlock = searchXPath("/ns:selfml/ns:DescriptionBlock/ns:variable");
        if (descriptionBlock.size() != 6) throw new EdipException
           ("DescriptionBlock contains " + descriptionBlock.size() +
            " variables instead of 6.");

        // The first two elements are substances
        List res;
        for (int i = 0;  i < 2;  i++) {
            Element e = (Element)descriptionBlock.get(i);
            res = findVariables(e);
            if (res.size() != 1) throw new EdipException
                                 ("Substance reference must have exactly 1 value.");
            e = (Element)res.get(0);
            self.addElement(getQName("substanceRef")).addText(e.getText());
        }

        // Add the block
        Element block = self.addElement(getQName("block"));
        block.addElement(getQName("indVar")).addAttribute("name", "X1");
        block.addElement(getQName("depVar")).addAttribute("name", "Y1");

        // Add the rows
        List[] v = new List[4];
        for (int i = 0;  i < v.length;  i++) {
            Element e = (Element)descriptionBlock.get(i+2);
            v[i] = findVariables(e);
            if (i > 0 && v[i].size() != v[0].size()) throw new EdipException
               ("The variables must have equal number of values");
        }
        Element[] ev = new Element[4];
        for (int i = 0, n = v[0].size();  i < n;  i++) {
            for (int j = 0;  j < 4;  j++) {
                ev[j] = (Element)v[j].get(i);
            }
            Element row = block.addElement(getQName("row"));
            row.addElement(getQName("p"))
               .addAttribute("e", ev[1].getText())
               .addText(ev[0].getText());
            row.addElement(getQName("p"))
               .addAttribute("e", ev[3].getText())
               .addText(ev[2].getText());
        }
        return document;
    }

/**
Finds variables of the specified name
@param variable name
@return list of value nodes
*/

    private List findVariables(String name) {
        return searchXPath
               ("/ns:selfml/ns:Variables/ns:variable/ns:value[../@name='" + name + "']");
    }


/**
Finds variables with the name specified in the <b>name</b> attribute of the supplied element
@param elem element
@return list of value nodes
*/

    private List findVariables(Element elem) {
        return findVariables(elem.attributeValue("name"));
    }

/**
Executes XPath expression on the parsed document
@param expression XPath expression
@return list of nodes
*/

    private List searchXPath(String expression) {
        XPath xpathSelector = DocumentHelper.createXPath(expression);
        xpathSelector.setNamespaceURIs(nsMap);
        return xpathSelector.selectNodes(document);
    }


}
